Enum polkadot_runtime_parachains::inclusion::pallet::Error [−][src]
pub enum Error<T> {
Show 24 variants
WrongBitfieldSize,
BitfieldDuplicateOrUnordered,
ValidatorIndexOutOfBounds,
InvalidBitfieldSignature,
UnscheduledCandidate,
CandidateScheduledBeforeParaFree,
WrongCollator,
ScheduledOutOfOrder,
HeadDataTooLarge,
PrematureCodeUpgrade,
NewCodeTooLarge,
CandidateNotInParentContext,
InvalidGroupIndex,
InsufficientBacking,
InvalidBacking,
NotCollatorSigned,
ValidationDataHashMismatch,
IncorrectDownwardMessageHandling,
InvalidUpwardMessages,
HrmpWatermarkMishandling,
InvalidOutboundHrmp,
InvalidValidationCodeHash,
ParaHeadMismatch,
BitfieldReferencesFreedCore,
// some variants omitted
}Expand description
Custom dispatch errors of this pallet.
Variants
Availability bitfield has unexpected size.
Multiple bitfields submitted by same validator or validators out of order by index.
Validator index out of bounds.
Invalid signature
Candidate submitted but para not scheduled.
Candidate scheduled despite pending candidate already existing for the para.
Candidate included with the wrong collator.
Scheduled cores out of order.
Head data exceeds the configured maximum.
Code upgrade prematurely.
Output code is too large
Candidate not in parent context.
Invalid group index in core assignment.
Insufficient (non-majority) backing.
Invalid (bad signature, unknown validator, etc.) backing.
Collator did not sign PoV.
The validation data hash does not match expected.
The downward message queue is not processed correctly.
At least one upward message sent does not pass the acceptance criteria.
The candidate didn’t follow the rules of HRMP watermark advancement.
The HRMP messages sent by the candidate is not valid.
The validation code hash of the candidate is not valid.
The para_head hash in the candidate descriptor doesn’t match the hash of the actual para head in the
commitments.
A bitfield that references a freed core, either intentionally or as part of a concluded invalid dispute.
Implementations