Enum polkadot_runtime_parachains::paras::ParaLifecycle [−][src]
pub enum ParaLifecycle {
Onboarding,
Parathread,
Parachain,
UpgradingParathread,
DowngradingParachain,
OffboardingParathread,
OffboardingParachain,
}Expand description
The possible states of a para, to take into account delayed lifecycle changes.
If the para is in a “transition state”, it is expected that the parachain is
queued in the ActionsQueue to transition it into a stable state. Its lifecycle
state will be used to determine the state transition to apply to the para.
Variants
Para is new and is onboarding as a Parathread or Parachain.
Para is a Parathread.
Para is a Parachain.
Para is a Parathread which is upgrading to a Parachain.
Para is a Parachain which is downgrading to a Parathread.
Parathread is queued to be offboarded.
Parachain is queued to be offboarded.
Implementations
Returns true if parachain is currently onboarding. To learn if the
parachain is onboarding as a parachain or parathread, look at the
UpcomingGenesis storage item.
Returns true if para is in a stable state, i.e. it is currently a parachain or parathread, and not in any transition state.
Returns true if para is currently treated as a parachain.
This also includes transitioning states, so you may want to combine
this check with is_stable if you specifically want Paralifecycle::Parachain.
Returns true if para is currently treated as a parathread.
This also includes transitioning states, so you may want to combine
this check with is_stable if you specifically want Paralifecycle::Parathread.
Returns true if para is currently offboarding.
Returns true if para is in any transitionary state.